==> 1.11.0.zip: vernissage/README.md <==
# Vernissage

<img src="Resources/01.png" width="200" > <img src="Resources/04.png" width="200" > <img src="Resources/05.png" width="200" > <img src="Resources/06.png" width="200" >

Vernissage is a simple and intuitive Pixelfed client that is focused on showcasing and sharing photos.
With Vernissage, you can browse through a timeline that is dedicated to photos only.
This means that you won't find any other types of media in the app, so you can focus solely on discovering and enjoying beautiful photography.

Our app features a clean and minimalistic interface that is designed to put the focus on the images.
You can easily like and comment on photos, as well as follow other users to keep up with their latest posts.

Vernissage is 100% free and open-source.

So, whether you're a professional photographer, an amateur enthusiast, or simply someone who loves to discover and share stunning photos,
Vernissage is the perfect app for you. Try it out today and join our growing community of passionate photo lovers.

It's built entirely in SwiftUI.

## Contributing

You can fork and clone repository. Change development team and bundle id. Do your changes and create a pull a request 👍.

Thank you in advance for any, even the smallest help, with the development of the project 💕!

## Translations

Creating new translation is pretty easy, all you need to do is to copy two folders:
 - `Vernissage/Localization/en.lproj`
 - `Vernissage/PixelfedKit/Sources/PixelfedKit/Resources/en.lproj`

In the name of the folders you have to put the code of the new language ([here](https://stackoverflow.com/a/13360348) you can find the languages codes).
Then you have to open files in these folders and translate them 🇯🇵🇫🇷🇨🇮🇧🇪. After translation create a Pull Request 👍.

From time to time you have to come back and translate lines which has been added since the last translation. 

## Technical debt
 - Use auto generated resources (Color/Images) instead static extensions (how to do this in separete Swift Packages?)
 - Enable swiftlint (https://github.com/realm/SwiftLint/issues/5053)
 - Investigate new (iOS 17) Observables
 - Check how to migrate to SwiftData (iOS 17)

==> 1.13.0.zip: vernissage/README.md <==
# Vernissage

<img src="Resources/01.png" width="200" > <img src="Resources/04.png" width="200" > <img src="Resources/05.png" width="200" > <img src="Resources/06.png" width="200" >

Vernissage is a simple and intuitive Pixelfed client that is focused on showcasing and sharing photos.
With Vernissage, you can browse through a timeline that is dedicated to photos only.
This means that you won't find any other types of media in the app, so you can focus solely on discovering and enjoying beautiful photography.

Our app features a clean and minimalistic interface that is designed to put the focus on the images.
You can easily like and comment on photos, as well as follow other users to keep up with their latest posts.

Vernissage is 100% free and open-source.

So, whether you're a professional photographer, an amateur enthusiast, or simply someone who loves to discover and share stunning photos,
Vernissage is the perfect app for you. Try it out today and join our growing community of passionate photo lovers.

It's built entirely in SwiftUI.

## Contributing

You can fork and clone repository. Change development team and bundle id. Do your changes and create a pull a request 👍.

Thank you in advance for any, even the smallest help, with the development of the project 💕!

## Translations

Creating new translation is pretty easy, all you need to do is to copy two folders:
 - `Vernissage/Localization/en.lproj`
 - `Vernissage/PixelfedKit/Sources/PixelfedKit/Resources/en.lproj`

In the name of the folders you have to put the code of the new language ([here](https://stackoverflow.com/a/13360348) you can find the languages codes).
Then you have to open files in these folders and translate them 🇯🇵🇫🇷🇨🇮🇧🇪. After translation create a Pull Request 👍.

From time to time you have to come back and translate lines which has been added since the last translation. 

## Technical debt

Things that should be implemented in version 2.0:

 - [ ] Use auto generated resources (Color/Images) instead static extensions (how to do this in separete Swift Packages?)
 - [ ] Move to xcstring (new Xcode transaction system)
 - [ ] Move to new Observable macro (iOS 17)
 - [ ] Migrate to SwiftData (iOS 17)
 - [ ] Use ViewModels
 - [ ] Add tips (new TipKit framework in iOS 17)
 - [ ] Enable swiftlint (https://github.com/realm/SwiftLint/issues/5053)
